@@ -11,7 +11,7 @@ extends qw(
     TAP::Formatter::Console
 );
 
-our $VERSION = '0.04_03';
+our $VERSION = '0.02';
 
 has _test_results => (
     is      => 'rw',
@@ -32,7 +32,7 @@ sub open_test {
 sub summary {
     my ($self, $aggregate) = @_;
 
-    $self->_save_results( $ENV{TAP_FORMATTER_BAMBOO_OUTFILE} || 'results.xml');
+    $self->_save_results('results.xml');
 
     return if $self->silent();
 
@@ -94,8 +94,6 @@ sub _save_results {
 }
 1;
 
-=pod
-
 =encoding utf8
 
 =head1 NAME
@@ -127,9 +125,7 @@ This module is based on TAP::Formatter::JUnit by Graham TerMarsch
 
 =over
 
-=item * if environment variable TAP_FORMATTER_BAMBOO_OUTFILE is present then it
-will be used as filepath for output XML (otherwise "results.xml file will be
-created in current directory)
+=item * resulting XML is saved in results.xml instead of putting it to the stdout
 
 =item * information about passing/failing tests is put to the STDOUT/STDERR respectively,
 so it can be watched in Bamboo's build logs (also live during build)
@@ -160,21 +156,11 @@ Save resulting XML in results.xml file.
 
 =head1 AUTHOR
 
-Piotr Piątkowski <pp@idea7.pl>
+Piotr Piatkowski <pp@idea7.pl>
 
-=head2 Patches, contributors
+Graham TerMarsch <cpan@howlingfrog.com> (original C<TAP::Formatter::JUnit>)
 
-=over 4
-
-=item * Bartłomiej Fulanty <starlight@cpan.org>
-
-=item * Bartosz Jakubski <bjakubski@cpan.org>
-
-=item * Graham TerMarsch <cpan@howlingfrog.com> (original C<TAP::Formatter::JUnit>)
-
-=back
-
-=head2 Credits from the original module:
+Credits from the original module:
 
 Many thanks to Andy Armstrong et al. for the B<fabulous> set of tests in
 C<Test::Harness>; they became the basis for the unit tests here.
